package com.tcctlo.law.controller;

import com.tcctlo.common.core.domain.AjaxResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.stereotype.Controller;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import com.tcctlo.law.service.IAuditRecordService;
import com.tcctlo.law.entity.AuditRecord;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.List;

/**
 * <p>
 * 审核记录表 前端控制器
 * </p>
 *
 * @author
 * @since 2025-02-25
 */

@RestController
@RequestMapping("/auditRecord")
public class AuditRecordController {


    @Autowired
    private IAuditRecordService iAuditRecordService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<AuditRecord> pageList = iAuditRecordService.list(current, size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        AuditRecord auditRecord = iAuditRecordService.getById(id);
        return AjaxResult.success(auditRecord);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody AuditRecord params) {
        AjaxResult ajaxResult = new AjaxResult();
        if (iAuditRecordService.create(params)) {
            ajaxResult.put("msg", "添加成功");
            ajaxResult.put("code", 200);
        }else {
            ajaxResult.put("msg", "添加失败");
            ajaxResult.put("code", 500);
        }
        return ajaxResult;
    }

    /**
     * 根据案件ID获取案件审核记录
     * @param caseId 案件ID
     * @return 生和记录
     */
    @GetMapping(value = "selectByCaseId/{caseId}")
    public AjaxResult selectByCaseId(@PathVariable("caseId") Long caseId) {
        List<AuditRecord> list = iAuditRecordService.selectByCaseId(caseId);
        return AjaxResult.success(list);
    }


    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iAuditRecordService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody AuditRecord params) {
        Integer result = iAuditRecordService.update(params);
        return AjaxResult.success(result);
    }
}
