package com.tcctlo.law.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.CollectionRecord;
import com.tcctlo.law.service.ICollectionRecordService;
import com.tcctlo.law.vo.CollectionRecordEnterVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 收款记录表 前端控制器
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */

@RestController
@RequestMapping("/collectionRecord")
public class CollectionRecordController {


    @Autowired
    private ICollectionRecordService iCollectionRecordService;

    @GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<CollectionRecord> pageList = iCollectionRecordService.list(current,size);
        return AjaxResult.success(pageList);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        CollectionRecord collectionRecord = iCollectionRecordService.getById(id);
        return AjaxResult.success(collectionRecord);
    }

    /**
     * 收费记录审核
     * @param map 参数
     * @return 数据集
     */
    @PostMapping(value = "/audit")
    public AjaxResult audit(@RequestBody Map<String, Long> map) {
        AjaxResult ajaxResult = null;
        Boolean res = iCollectionRecordService.audit(map);
        if (res){
            ajaxResult = AjaxResult.success();
            return ajaxResult;
        }else {
            ajaxResult = AjaxResult.error();
            return ajaxResult;
        }
    }

    /**
     * 缴费记录删除
     * @param params 案件ID、缴费记录ID、关联缴费记录文件ID
     * @return 是否删除成功
     */
    @PostMapping(value = "/deleteLogic")
    public AjaxResult deleteLogic(@RequestBody Map<String, Long> params) {
        AjaxResult ajaxResult = null;
        Boolean res = iCollectionRecordService.deleteLogic(params);
        if (res){
            ajaxResult = AjaxResult.success();
            return ajaxResult;
        }else {
            ajaxResult = AjaxResult.error();
            return ajaxResult;
        }
    }

    /**
     * 根据案件ID查询缴费记录
     * @param caseId 案件ID
     * @return 缴费记录
     */
    @GetMapping(value = "selectByCaseId/{caseId}")
    public AjaxResult selectByCaseId(@PathVariable("caseId") Long caseId) {
        List<CollectionRecordEnterVO> collectionRecordEnterVOS = iCollectionRecordService.selectByCaseId(caseId);
        return AjaxResult.success(collectionRecordEnterVOS);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody CollectionRecord params) {
        Integer result = iCollectionRecordService.create(params);
        return AjaxResult.success(result);
    }


    /**
     * 批量缴费
     * @param params 参数
     * @return 结果集
     */
    @PostMapping(value = "/casePaymentBatch")
    public AjaxResult casePaymentBatch(@RequestBody List<CollectionRecordEnterVO> params) {

        AjaxResult ajaxResult = null;
        Boolean res = iCollectionRecordService.casePaymentBatch(params);
        if (res){
            ajaxResult = AjaxResult.success();
            return ajaxResult;
        }else {
            ajaxResult = AjaxResult.error();
            return ajaxResult;
        }
    }

    /**
     * 案件缴费
     * @param params 参数
     * @return 缴费结果
     */
    @PostMapping(value = "/casePayment")
    public AjaxResult casePayment(@RequestBody CollectionRecordEnterVO params) {

        iCollectionRecordService.casePayment(params);
        return AjaxResult.success();
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result =  iCollectionRecordService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody CollectionRecord params) {
        Integer result = iCollectionRecordService.update(params);
        return AjaxResult.success(result);
    }
}
