package com.tcctlo.law.tools;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDate;

@Component
public class RedisGenerateCaseNo {

    @Autowired
    private StringRedisTemplate stringRedisTemplate;

    private static final String COUNTER_KEY_PREFIX = "DAILY_COUNTER:"; // Redis键前缀


    /**
     * 生成案件编号
     * @return 案件编号
     */
    public String generateCaseNo(Integer businessClassify) {

        String currentDate = LocalDate.now().toString().replace("-", "");  //获取当前日期

        String counterKey = COUNTER_KEY_PREFIX + currentDate;   //组装Redis的Key

        Long counter = stringRedisTemplate.opsForValue().increment(counterKey);

        switch (businessClassify){
            case 0:
                return String.format("MS-%s-%03d", currentDate, counter);
            case 1:
                return String.format("XS-%s-%03d", currentDate, counter);
            case 2:
                return String.format("XZFY-%s-%03d", currentDate, counter);
            case 3:
                return String.format("QYCN-%s-%03d", currentDate, counter);
            case 4:
               return String.format("QYZX-%s-%03d", currentDate, counter);
            case 5:
                return String.format("QTFSS-%s-%03d", currentDate, counter);
            case 6:
                return String.format("LDZY-%s-%03d", currentDate, counter);
            case 7:
                return String.format("SHZC-%s-%03d", currentDate, counter);
        }

        return String.format("DEFAULT-%s-%03d", currentDate, counter);
    }
}
